@@ -103,10 +103,14 @@ def invoke_backend_service_as_proxy(method, function_path, json_data=dict(), req
                 if response_token:
                     raise WsResponseError('Backend server didn\'t respond with a token')
 
-            resp = HttpResponse(response_data, content_type='application/json')
+            headers = dict()
             for header, value in response.getheaders():
-                print value
-                resp[header] = value
+                headers[header] = value
+
+            if response.status is 204:
+                resp = Response(status=response.status, headers=headers, content_type='application/json')
+            else:
+                resp = Response(data=response_data, status=response.status, headers=headers, content_type='application/json')
 
             return resp
         else:
