@@ -28,10 +28,10 @@ def expose_service(methods, public=False):
                                 raise PermissionDenied
 
                             request.META[proxy_server.HTTP_USER_TOKEN] = response[proxy_server.USER_TOKEN]
-                            return csrf_exempt(api_view(methods)(view_func)(request, *args, **kwargs))
+                            return api_view(methods)(view_func)(request, *args, **kwargs)
 
                         elif public is True and request.META.get(proxy_server.HTTP_USER_TOKEN) is None:
-                            return csrf_exempt(api_view(methods)(view_func)(request, *args, **kwargs))
+                            return api_view(methods)(view_func)(request, *args, **kwargs)
                     else:
                         return api_view(methods)(view_func)(request, *args, **kwargs)
             raise PermissionDenied
